@@ -180,7 +180,6 @@ class Logger:
     def set_path(self, path: str):
 
         self._path = path.rstrip('/')
-        print('SET PATH: {}'.format(self._path))
 
     def start(self, _converting=False) -> str:
 
@@ -188,8 +187,6 @@ class Logger:
 
         Path(folder).mkdir(parents=True, exist_ok=True)
 
-        print('LOG FOLDER: {}'.format(folder))
-
         if not _converting:
             self.messages.write_message('Logging started. Path: {}'.format(folder))
         else:
