@@ -308,13 +308,24 @@ class Parser:
 
         def get_common_data():
 
-            status = unpack('<B', data[2:3])[0]
+            common = {'version': None,
+                      'offsetOfData': None,
+                      'flags.posixTime': None,
+                      'timeStamp': None,
+                      'microSeconds': None}
 
-            common = {'version': unpack('<B', data[0:1])[0],
-                      'offsetOfData': unpack('<B', data[1:2])[0],
-                      'flags.posixTime': _get_status(status_bits=status, bit=0),
-                      'timeStamp': unpack('<I', data[4:8])[0],
-                      'microSeconds': unpack('<I', data[8:12])[0]}
+            try:
+                status = unpack('<B', data[2:3])[0]
+
+                common = {'version': unpack('<B', data[0:1])[0],
+                          'offsetOfData': unpack('<B', data[1:2])[0],
+                          'flags.posixTime': _get_status(status_bits=status, bit=0),
+                          'timeStamp': unpack('<I', data[4:8])[0],
+                          'microSeconds': unpack('<I', data[8:12])[0]}
+
+            except struct.error:
+                self.messages.write_warning('Failed to unpack common data')
+                self.messages.write_warning(data)
 
             return common
 
